==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebColumnMovingStartEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingStartEventArgsDetailDescriptionMetadata } from "./WebColumnMovingStartEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDescription } from "./WebColumnMovingStartEventArgsDescription";
/**
 * @hidden
 */
var WebColumnMovingStartEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnMovingStartEventArgsDescriptionMetadata, _super);
    function WebColumnMovingStartEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingStartEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnMovingStartEventArgsDescriptionMetadata.a == null) {
            WebColumnMovingStartEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingStartEventArgsDescriptionMetadata.c(WebColumnMovingStartEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnMovingStartEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebColumnMovingStartEventArgsDescriptionMetadata.a);
        WebColumnMovingStartEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebColumnMovingStartEventArgsDetail");
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.d = function (a) {
        WebColumnMovingStartEventArgsDescriptionMetadata.b(a);
        a.ad("WebColumnMovingStartEventArgs", function () { return new WebColumnMovingStartEventArgsDescription(); });
        a.ac("WebColumnMovingStartEventArgs", WebColumnMovingStartEventArgsDescriptionMetadata.a);
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.$t = markType(WebColumnMovingStartEventArgsDescriptionMetadata, 'WebColumnMovingStartEventArgsDescriptionMetadata');
    WebColumnMovingStartEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDescriptionMetadata;
}(Base));
export { WebColumnMovingStartEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebColumnMovingStartEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingStartEventArgsDetailDescriptionMetadata } from "./WebColumnMovingStartEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDescription } from "./WebColumnMovingStartEventArgsDescription";
/**
 * @hidden
 */
var WebColumnMovingStartEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnMovingStartEventArgsDescriptionMetadata, _super);
    function WebColumnMovingStartEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingStartEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnMovingStartEventArgsDescriptionMetadata.a == null) {
            WebColumnMovingStartEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingStartEventArgsDescriptionMetadata.c(WebColumnMovingStartEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnMovingStartEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebColumnMovingStartEventArgsDescriptionMetadata.a);
        WebColumnMovingStartEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebColumnMovingStartEventArgsDetail");
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.d = function (a) {
        WebColumnMovingStartEventArgsDescriptionMetadata.b(a);
        a.ae("WebColumnMovingStartEventArgs", function () { return new WebColumnMovingStartEventArgsDescription(); });
        a.ad("WebColumnMovingStartEventArgs", WebColumnMovingStartEventArgsDescriptionMetadata.a);
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.$t = markType(WebColumnMovingStartEventArgsDescriptionMetadata, 'WebColumnMovingStartEventArgsDescriptionMetadata');
    WebColumnMovingStartEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDescriptionMetadata;
}(Base));
export { WebColumnMovingStartEventArgsDescriptionMetadata };
